==> xmpp-core-common-0.8.2-sources.jar: rocks/xmpp/core/stanza/model/server/package-info.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/**
 * Provides <a href="https://xmpp.org/rfcs/rfc6120.html#stanzas">XML Stanzas</a> from the <a href="https://xmpp.org/rfcs/rfc6120.html#schemas-server">Server Namespace</a> ({@linkplain rocks.xmpp.core.stanza.model.server.ServerMessage}, {@linkplain rocks.xmpp.core.stanza.model.server.ServerPresence} and {@linkplain rocks.xmpp.core.stanza.model.server.ServerIQ}).
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlSchema(namespace = "jabber:server", elementFormDefault = XmlNsForm.QUALIFIED) package rocks.xmpp.core.stanza.model.server;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlNsForm;
import javax.xml.bind.annotation.XmlSchema;

==> xmpp-core-common-0.9.1-sources.jar: rocks/xmpp/core/stanza/model/server/package-info.java <==
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2014-2016 Christian Schudt
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/**
 * Provides <a href="https://xmpp.org/rfcs/rfc6120.html#stanzas">XML Stanzas</a> from the <a
 * href="https://xmpp.org/rfcs/rfc6120.html#schemas-server">Server Namespace</a> ({@linkplain
 * rocks.xmpp.core.stanza.model.server.ServerMessage}, {@linkplain rocks.xmpp.core.stanza.model.server.ServerPresence}
 * and {@linkplain rocks.xmpp.core.stanza.model.server.ServerIQ}).
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlSchema(namespace = "jabber:server", elementFormDefault = XmlNsForm.QUALIFIED)
package rocks.xmpp.core.stanza.model.server;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlNsForm;
import javax.xml.bind.annotation.XmlSchema;
